%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% test_method:
%
% A very simple script that generates a synthetic problem, performs MCMC,
% and then evalutes a simple threshold estimator for the bi-directed error
% structure.
%
% Created by: Ricardo Silva, London
% University College London
%
% Current version: 26/10/2011

simulate_latent_sem
[z_B w C_B C_X miss_mean] = sem_spikebd_sampler(y_data, dir_graph, ...
                            fix_W, fix_W_v, fixG_B, fixG_B_g, M, pw, u_B, ...
                            U_B, u_X, U_X, mars_matrix, burn_in);

z_B_hat = mean(z_B, 3);  % Estimate of bi-directed edge inclusion probability
C_B_hat = mean(C_B, 3);  % Estimate of error covariance matrix
BG_hat  = z_B_hat > 0.5; % Estimate of bi-directed structure

disp('Correctly identified entries in the bi-directed graph:')
disp(BG_hat == bidir_graph)

corr_est = corr(C_B_hat); corr_est(BG_hat == 0) = 0; % Threshold correlation estimator
for j = 1:size(corr_est, 1); corr_est(j, j) = 1; end;

colormap(gray)
subplot(2, 3, 1); imagesc(BG_hat); title('Estimated graph', 'FontSize', 14)
subplot(2, 3, 2); imagesc(bidir_graph); title('True graph', 'FontSize', 14)
subplot(2, 3, 3); imagesc(BG_hat ~= bidir_graph); title('Structural errors', 'FontSize', 14)
subplot(2, 3, 4); imagesc(corr_est); title('Estimated correlation', 'FontSize', 14)
subplot(2, 3, 5); imagesc(corr(Sigma_error)); title('True correlation', 'FontSize', 14)
subplot(2, 3, 6); imagesc(corr_est - corr(Sigma_error)); title('Difference', 'FontSize', 14)
